from .auth_token_create import *
from .auth_token_refresh_create import *
from .auth_token_refresh_retrieve import *
from .auth_token_retrieve import *
from .auth_token_verify_create import *

ENDPOINT_NAMES = [
    "auth_token_retrieve",
    "auth_token_create",
    "auth_token_refresh_retrieve",
    "auth_token_refresh_create",
    "auth_token_verify_create",
]
