from .workflows_api_v1_workflows_adjust_create import *
from .workflows_api_v1_workflows_retrieve import *
from .workflows_api_v1_workflows_retrieve_2 import *
from .workflows_healthy_retrieve import *
from .workflows_retrieve import *

ENDPOINT_NAMES = [
    "workflows_retrieve",
    "workflows_api_v1_workflows_retrieve",
    "workflows_api_v1_workflows_retrieve_2",
    "workflows_api_v1_workflows_adjust_create",
    "workflows_healthy_retrieve",
]
